@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 #--------------------------------------------------------------------------
 
@@ -77,6 +77,8 @@ a valid page is returned, the following fields are returned via the book hash:
 
 The book_link and image_link refer back to the Word Power website.
 
+=back
+
 =cut
 
 sub search {
@@ -92,22 +94,16 @@ sub search {
                  || (length $isbn == 10 && $isbn ne $self->convert_to_isbn10($ean)));
 
     my $mech = WWW::Mechanize->new();
-    $mech->agent_alias( 'Windows IE 6' );
+    $mech->agent_alias( 'Linux Mozilla' );
     $mech->add_header('Accept-Encoding' => undef);
 
     eval { $mech->get( SEARCH . $isbn ) };
     return $self->handler("WordPower website appears to be unavailable.")
 	    if($@ || !$mech->success() || !$mech->content());
 
-    my $pattern = $isbn;
-    if(length $isbn == 10) {
-        $pattern = '978' . $isbn;
-        $pattern =~ s/.$/./;
-    }
-
     my $content = $mech->content;
-    my ($link) = $content =~ m!($URL2$pattern$URL3)!si;
-#print STDERR "\n# link1=[$URL2$pattern$URL3]\n";
+    my ($link) = $content =~ m!($URL2$ean$URL3)!si;
+#print STDERR "\n# link1=[$URL2$ean$URL3]\n";
 #print STDERR "\n# link2=[$URL1$link]\n";
 #print STDERR "\n# content1=[\n$content\n]\n";
 #print STDERR "\n# is_html=".$mech->is_html().", content type=".$mech->content_type()."\n";
@@ -149,6 +145,11 @@ sub search {
     ($data->{width})            = $html =~ m!<td[^>]+>Width \(mm\)</td>\s*<td[^>]+>([^<]+)</td>!s;
     ($data->{height})           = $html =~ m!<td[^>]+>Height \(mm\)</td>\s*<td[^>]+>([^<]+)</td>!s;
 
+    for my $key (qw(weight width height)) {
+        next    unless($data->{$key});
+        $data->{$key} =~ s/\.0+$//;
+    }
+
     $data->{author} =~ s!<[^>]+>!!g                     if($data->{author});
     if($data->{description}) {
         $data->{description} =~ s!<script.*!!si;
@@ -201,79 +202,6 @@ sub search {
 	return $self->book;
 }
 
-=item C<convert_to_ean13()>
-
-Given a 10/13 character ISBN, this function will return the correct 13 digit
-ISBN, also known as EAN13.
-
-=item C<convert_to_isbn10()>
-
-Given a 10/13 character ISBN, this function will return the correct 10 digit 
-ISBN.
-
-=back
-
-=cut
-
-sub convert_to_ean13 {
-	my $self = shift;
-    my $isbn = shift;
-    my $prefix;
-
-    return  unless(length $isbn == 10 || length $isbn == 13);
-
-    if(length $isbn == 13) {
-        return  if($isbn !~ /^(978|979)(\d{10})$/);
-        ($prefix,$isbn) = ($1,$2);
-    } else {
-        return  if($isbn !~ /^(\d{10}|\d{9}X)$/);
-        $prefix = '978';
-    }
-
-    my $isbn13 = '978' . $isbn;
-    chop($isbn13);
-    my @isbn = split(//,$isbn13);
-    my ($lsum,$hsum) = (0,0);
-    while(@isbn) {
-        $hsum += shift @isbn;
-        $lsum += shift @isbn;
-    }
-
-    my $csum = ($lsum * 3) + $hsum;
-    $csum %= 10;
-    $csum = 10 - $csum  if($csum != 0);
-
-    return $isbn13 . $csum;
-}
-
-sub convert_to_isbn10 {
-	my $self = shift;
-    my $ean  = shift;
-    my ($isbn,$isbn10);
-
-    return  unless(length $ean == 10 || length $ean == 13);
-
-    if(length $ean == 13) {
-        return  if($ean !~ /^(?:978|979)(\d{9})\d$/);
-        ($isbn,$isbn10) = ($1,$1);
-    } else {
-        return  if($ean !~ /^(\d{9})[\dX]$/);
-        ($isbn,$isbn10) = ($1,$1);
-    }
-
-	return  if($isbn < 0 or $isbn > 999999999);
-
-	my ($csum, $pos, $digit) = (0, 0, 0);
-    for ($pos = 9; $pos > 0; $pos--) {
-        $digit = $isbn % 10;
-        $isbn /= 10;             # Decimal shift ISBN for next time 
-        $csum += ($pos * $digit);
-    }
-    $csum %= 11;
-    $csum = 'X'   if ($csum == 10);
-    return sprintf "%09d%s", $isbn10, $csum;
-}
-
 1;
 
 __END__
@@ -310,7 +238,7 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2013 Barbie for Miss Barbell Productions
+  Copyright (C) 2010-2014 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
